import datetime

from django.db import models

class CreateTimeBaseObject(models.Model):
    created = models.DateTimeField(auto_now_add=True,
        default=datetime.datetime.now())
    modified = models.DateTimeField(auto_now=True,
        default=datetime.datetime.now())
    active = models.BooleanField(default=True, db_index=True)

    class Meta:
        abstract = True

class Group(CreateTimeBaseObject):
    name = models.CharField(max_length=255, unique=True)

class Plugin(CreateTimeBaseObject):
    name = models.CharField(max_length=255)
    title = models.CharField(max_length=255)
    version = models.CharField(max_length=32)
    compability = models.ManyToManyField('FuelVersion', related_name='plugins', )
    description = models.CharField(max_length=4096)
    binarylink = models.CharField(max_length=1024)
    checksumlink = models.CharField(max_length=1024)
    doclink = models.CharField(max_length=1024)
    author = models.CharField(max_length=255)
    group = models.ManyToManyField('Group', related_name='plugins')

    class Meta:
        unique_together = ('name', 'version')

class FuelVersion(CreateTimeBaseObject):
    name = models.CharField(max_length=16)

    def __str__(self):
        return self.name
