import os
import urllib2
import yaml

from django.conf import settings
from django.shortcuts import render_to_response, HttpResponse
from django.views.decorators.csrf import csrf_exempt

from plugins_catalog.models import FuelVersion, Group, Plugin
from security.decorators import token_auth

def index(request):
    groups = Group.objects.all()
    return render_to_response(
        'plugins_catalog/index.html',
        {'groups': groups}
    )

@csrf_exempt
@token_auth
def sync(request):
    if request.method != 'POST':
        return HttpResponse(
            content=yaml.dump(
                {'status': 'error', 'description': 'Request method should be POST'},
                default_flow_style=False),
            content_type='application/yaml',
            status=400,
        )

    ua = urllib2.urlopen('%s/metadata.yaml' % settings.PLUGINS_REPOSITORY_URL)
    metadata = yaml.load(ua.read())

    for plugin_metadata in metadata:
        plugin, pcreated = Plugin.objects.get_or_create(
            name=plugin_metadata['name'], version=plugin_metadata['version'])

        if 'groups' in plugin_metadata:
            groups = plugin_metadata['groups']
        else:
            groups = ['other']

        if 'fuel_version' in plugin_metadata:
            for fuel_version in plugin_metadata['fuel_version']:
                version, vcreated = FuelVersion.objects.get_or_create(
                    name=fuel_version
                )

                if vcreated:
                    version.save()
                if version not in plugin.compability.all():
                    plugin.compability.add(version)

        for plugin_group in groups:
            group, gcreated = Group.objects.get_or_create(name=plugin_group)

            if gcreated:
                group.save()

            if group not in plugin.group.all():
                plugin.group.add(group)


        for plugin_group in plugin.group.all():
            if plugin_group.name not in groups:
                plugin.group.remove(plugin_group)

        plugin.name = plugin_metadata['name']
        plugin.title = plugin_metadata['title']
        plugin.version = plugin_metadata['version']
        plugin.description = plugin_metadata['description']
        plugin.binarylink = '%s/%s' % (
            settings.PLUGINS_REPOSITORY_URL, plugin_metadata['binary'])
        plugin.doclink = '%s/%s' % (
            settings.PLUGINS_REPOSITORY_URL, plugin_metadata['doc'])

        plugin.save()


    return HttpResponse(
        content=yaml.dump(
            {'status': 'ok', 'description': 'Looks like everything is good'},
            default_flow_style=False),
        content_type='application/yaml',
        status=200,
    )
